@@ -9,7 +9,7 @@ use LWP::UserAgent;
 use URI::Escape qw(uri_escape_utf8);
 use Amazon::S3::Thin::SignerV2;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my $METADATA_PREFIX      = 'x-amz-meta-';
 
@@ -77,6 +77,12 @@ sub get_object {
     return $self->ua->request($request);
 }
 
+sub head_object {
+    my ($self, $bucket, $key) = @_;
+    my $request = $self->_compose_request('HEAD', $self->_uri($bucket, $key));
+    return $self->ua->request($request);
+}
+
 sub delete_object {
     my ($self, $bucket, $key) = @_;
     my $request = $self->_compose_request('DELETE', $self->_uri($bucket, $key));
@@ -237,7 +243,7 @@ __END__
 
 =head1 NAME
 
-Amazon::S3::Thin - A thin, ligthweight, low-level Amazon S3 client
+Amazon::S3::Thin - A thin, lightweight, low-level Amazon S3 client
 
 =head1 SYNOPSIS
 
@@ -266,6 +272,8 @@ Amazon::S3::Thin - A thin, ligthweight, low-level Amazon S3 client
                               {prefix => "foo", delimter => "/"}
                              );
 
+  $response = $s3client->head_object($bucket, $key);
+
 You can also pass any useragent as you like
 
   my $s3client = Amazon::S3::Thin->new(
@@ -278,42 +286,169 @@ You can also pass any useragent as you like
 
 =head1 DESCRIPTION
 
-Amazon::S3::Thin - A thin, ligthweight, low-level Amazon S3 client.
+Amazon::S3::Thin is a thin, lightweight, low-level Amazon S3 client.
+It offers the following features:
 
 =over
 
 =item Low Level
 
-It returns HTTP::Response. So you can inspect easily what's happening inside , and can handle error as you like.
+It returns an L<HTTP::Response> object so you can easily inspect
+what's happening inside, and can handle errors as you like.
 
 
 =item Low Dependency
 
-It does require no XML::* modules, so that installation be easy;
+It does not require any XML::* modules, so installation is easy;
 
 =item Low Learning Cost
 
-The interfaces are designed to follow S3 official REST APIs. So it is easy to learn.
+The interfaces are designed to follow S3 official REST APIs.
+So it is easy to learn.
 
 =back
 
-=head1 comparison to precedent modules
+=head2 Comparison to precedent modules
 
-There are already usuful modules L<Amazon::S3> and L<Net::Amazon::S3>.
-The 2 precedent modules provides "a Perlish interface", which is easy to understand for Perl programmers.
-But they also hide low-level behaviors.
-For example, the "get_key" method returns undef on 404 status and raises exception on 5xx status.
+There are already some useful modules like L<Amazon::S3>, L<Net::Amazon::S3>
+ on CPAN. They provide a "Perlish" interface, which looks pretty
+ for Perl programmers, but they also hide low-level behaviors.
+For example, the "get_key" method translate HTTP status 404 into C<undef> and
+ HTTP 5xx status into exception.
 
-In some situations, it is very important to see raw HTTP communications.
+In some situations, it is very important to see the raw HTTP communications.
 That's why I made this module.
 
-=head1 TO DO
+=head1 CONSTRUCTOR
+
+=head2 new( \%params )
+
+B<Receives:> hashref with options.
+
+B<Returns:> Amazon::S3::Thin object
+
+It can receive the following arguments:
+
+=over 4
+
+=item * C<aws_access_key_id> (B<REQUIRED>) - an access key id
+of your credentials.
+
+=item * C<aws_secret_access_key> (B<REQUIRED>) - an secret access key
+ of your credentials.
+
+=item * C<secure> - whether to use https or not. Default is 0 (http).
+
+=item * C<host> - the base host to use. Default is 'I<s3.amazonaws.com>'.
+
+=item * C<ua> - a user agent object, compatible with LWP::UserAgent.
+Default is an instance of L<LWP::UserAgent>.
+
+=back
+
+=head1 ACCESSORS
+
+The following accessors are provided. You can use them to get/set your
+object's attributes.
+
+=head2 secure
+
+Whether to use https (1) or http (0) when connecting to S3.
+
+=head2 host
+
+The base host to use for connecting to S3.
+
+=head2 ua
+
+The user agent used internally to perform requests and return responses.
+If you set this attribute, please make sure you do so with an object
+compatible with L<LWP::UserAgent> (i.e. providing the same interface).
+
+=head1 METHODS
+
+=head2 get_object( $bucket, $key )
+
+B<Arguments>: a string with the bucket name, and a string with the key name.
+
+B<Returns>: an L<HTTP::Response> object for the request. Use the C<content()>
+method on the returned object to read the contents:
+
+    my $res = $s3->get_object( 'my.bucket', 'my/key.ext' );
+
+    if ($res->is_success) {
+        my $content = $res->content;
+    }
+
+The GET operation retrieves an object from Amazon S3.
+
+For more information, please refer to
+L<< Amazon's documentation for GET|http://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectGET.html >>.
+
+=head2 delete_object( $bucket, $key )
+
+B<Arguments>: a string with the bucket name, and a string with the key name.
+
+B<Returns>: an L<HTTP::Response> object for the request.
+
+The DELETE operation removes the null version (if there is one) of an object
+and inserts a delete marker, which becomes the current version of the
+object. If there isn't a null version, Amazon S3 does not remove any objects.
+
+Use the response object to see if it succeeded or not.
+
+For more information, please refer to
+L<< Amazon's documentation for DELETE|http://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectDELETE.html >>.
+
+=head2 copy_object( $src_bucket, $src_key, $dst_bucket, $dst_key )
+
+B<Arguments>: a list with source (bucket, key) and destination (bucket, key)
+
+B<Returns>: an L<HTTP::Response> object for the request.
+
+This method is a variation of the PUT operation as described by
+Amazon's S3 API. It creates a copy of an object that is already stored
+in Amazon S3. This "PUT copy" operation is the same as performing a GET
+from the old bucket/key and then a PUT to the new bucket/key.
+
+For more information, please refer to
+L<< Amazon's documentation for COPY|http://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectCOPY.html >>.
+
+=head2 put_object( $bucket, $key, $content [, $headers] )
+
+B<Arguments>:
+
+a list of the following items, in order:
+
+=over 4
+
+=item 1. bucket - a string with the destination bucket
+
+=item 2. key - a string with the destination key
+
+=item 3. content - a string with the content to be uploaded
+
+=item 4. headers (B<optional>) - hashref with extra headr information
+
+=back
+
+B<Returns>: an L<HTTP::Response> object for the request.
+
+The PUT operation adds an object to a bucket. Amazon S3 never adds partial
+objects; if you receive a success response, Amazon S3 added the entire
+object to the bucket.
+
+For more information, please refer to
+L<< Amazon's documentation for PUT|http://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectPUT.html >>.
+
+
+=head1 TODO
 
 lots of APIs are not implemented yet.
 
 =head1 REPOSITORY
 
-https://github.com/DQNEO/Amazon-S3-Thin
+L<https://github.com/DQNEO/Amazon-S3-Thin>
 
 =head1 LICENSE
 
@@ -329,16 +464,14 @@ DQNEO
 =head2 ORIGINAL AUTHOR
 
 Timothy Appnel <tima@cpan.org> L<Amazon::S3>
-https://github.com/tima/perl-amazon-s3
+L<https://github.com/tima/perl-amazon-s3>
 
 =head1 SEE ALSO
 
 L<Amazon::S3>, L<Net::Amazon::S3>
 
-Amazon S3 API Reference : REST API
-http://docs.aws.amazon.com/AmazonS3/latest/API/APIRest.html
+L<Amazon S3 API Reference : REST API|http://docs.aws.amazon.com/AmazonS3/latest/API/APIRest.html>
 
-Amazon S3 API Reference : List of Error Codes
-http://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList
+L<Amazon S3 API Reference : List of Error Codes|http://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList>
 
 =cut
